@@ -1,5 +1,5 @@
 package Log::Dispatch::FileRotate;
-$Log::Dispatch::FileRotate::VERSION = '1.34';
+$Log::Dispatch::FileRotate::VERSION = '1.35';
 # ABSTRACT: Log to Files that Archive/Rotate Themselves
 
 require 5.005;
@@ -647,7 +647,7 @@ sub debug {
 
     return unless $self->{debug};
 
-    warn localtime . " $$ $message\n";
+    warn localtime() . " $$ $message\n";
 
     return;
 }
@@ -672,7 +672,7 @@ Log::Dispatch::FileRotate - Log to Files that Archive/Rotate Themselves
 
 =head1 VERSION
 
-version 1.34
+version 1.35
 
 =head1 SYNOPSIS
 
@@ -994,13 +994,17 @@ And thanks to Stephen Gordon for his more portable code on lockfile naming.
 
 =head1 SOURCE
 
-The development version is on github at L<https://github.com/mschout/perl-log-dispatch-filerotate>
-and may be cloned from L<git://github.com/mschout/perl-log-dispatch-filerotate.git>
+The development version is on github at L<http://https://github.com/mschout/perl-log-dispatch-filerotate>
+and may be cloned from L<git://https://github.com/mschout/perl-log-dispatch-filerotate.git>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to bug-log-dispatch-filerotate@rt.cpan.org or through the web interface at:
- http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch-FileRotate
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/mschout/perl-log-dispatch-filerotate/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
